Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(740)

Unified Diff: chrome/browser/chromeos/login/profile_auth_data.h

Issue 11742037: Make ServerBoundCertStore interface async, move SQLiteServerBoundCertStore load onto DB thread. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix login_utils_browsertest Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/profile_auth_data.h
diff --git a/chrome/browser/chromeos/login/profile_auth_data.h b/chrome/browser/chromeos/login/profile_auth_data.h
index 9cbd7f0a78ba00565884e014aaccbec23787d11a..a7805e4db2ac2ab1495ca47c9a04ba43547d3c4d 100644
--- a/chrome/browser/chromeos/login/profile_auth_data.h
+++ b/chrome/browser/chromeos/login/profile_auth_data.h
@@ -18,12 +18,12 @@ class ProfileAuthData {
public:
// Transfers proxy authentication cache and optionally |transfer_cookies| and
// server bound certs from the profile that was used for authentication.
// |cookies_transfered_callback| will be called on UI thread after cookie
// transfer part of this operation is completed.
static void Transfer(Profile* from_profile,
Profile* to_profile,
bool transfer_cookies,
- const base::Closure& cookies_transfered_callback);
+ const base::Closure& completion_callback);
private:
DISALLOW_IMPLICIT_CONSTRUCTORS(ProfileAuthData);
@@ -18,12 +18,12 @@ class ProfileAuthData {
// Transfers proxy authentication cache and optionally |transfer_cookies| and
// server bound certs from the profile that was used for authentication.
- // |cookies_transfered_callback| will be called on UI thread after cookie
- // transfer part of this operation is completed.
+ // |completion_callback| will be called on UI thread after the operation is
+ // completed.
static void Transfer(Profile* from_profile,
Profile* to_profile,

Powered by Google App Engine
This is Rietveld 408576698